==> airdcpp-webui-1.0.4.tgz: package/src/utils/semantic.js <==
import 'semantic-ui/semantic.min.css';

// Requiring the styles separately would reduce the gzipped size by about 30 kilobytes
// Possibly change later, the changed order of rules causes issues that need to be fixed

/*import 'semantic-ui/components/accordion.min.css';
import 'semantic-ui/components/breadcrumb.min.css';
import 'semantic-ui/components/button.min.css';
import 'semantic-ui/components/checkbox.min.css';
import 'semantic-ui/components/container.min.css';
import 'semantic-ui/components/dimmer.min.css';
import 'semantic-ui/components/divider.min.css';
import 'semantic-ui/components/dropdown.min.css';
import 'semantic-ui/components/flag.min.css';
import 'semantic-ui/components/form.min.css';
import 'semantic-ui/components/grid.min.css';
import 'semantic-ui/components/header.min.css';
import 'semantic-ui/components/icon.min.css';
import 'semantic-ui/components/input.min.css';
import 'semantic-ui/components/label.min.css';
import 'semantic-ui/components/list.min.css';
import 'semantic-ui/components/loader.min.css';
import 'semantic-ui/components/menu.min.css';
import 'semantic-ui/components/message.min.css';
import 'semantic-ui/components/menu.min.css';
import 'semantic-ui/components/modal.min.css';
import 'semantic-ui/components/popup.min.css';
import 'semantic-ui/components/progress.min.css';
import 'semantic-ui/components/reset.min.css';
import 'semantic-ui/components/progress.min.css';
import 'semantic-ui/components/search.min.css';
import 'semantic-ui/components/segment.min.css';
import 'semantic-ui/components/sidebar.min.css';
import 'semantic-ui/components/site.min.css';
import 'semantic-ui/components/table.min.css';
import 'semantic-ui/components/transition.min.css';*/

import 'semantic-ui/components/accordion';
import 'semantic-ui/components/checkbox';
import 'semantic-ui/components/dimmer';
import 'semantic-ui/components/dropdown';
import 'semantic-ui/components/modal';
import 'semantic-ui/components/popup';
import 'semantic-ui/components/sidebar';
import 'semantic-ui/components/transition';

==> airdcpp-webui-1.1.2.tgz: package/src/utils/semantic.js <==
import 'semantic-ui/components/accordion.min.css';
import 'semantic-ui/components/breadcrumb.min.css';
import 'semantic-ui/components/button.min.css';
import 'semantic-ui/components/checkbox.min.css';
import 'semantic-ui/components/container.min.css';
import 'semantic-ui/components/dimmer.min.css';
import 'semantic-ui/components/divider.min.css';
import 'semantic-ui/components/dropdown.min.css';
import 'semantic-ui/components/flag.min.css';
import 'semantic-ui/components/form.min.css';
import 'semantic-ui/components/grid.min.css';
import 'semantic-ui/components/header.min.css';
import 'semantic-ui/components/icon.min.css';
import 'semantic-ui/components/input.min.css';
import 'semantic-ui/components/label.min.css';
import 'semantic-ui/components/list.min.css';
import 'semantic-ui/components/loader.min.css';
import 'semantic-ui/components/menu.min.css';
import 'semantic-ui/components/message.min.css';
import 'semantic-ui/components/menu.min.css';
import 'semantic-ui/components/modal.min.css';
import 'semantic-ui/components/popup.min.css';
import 'semantic-ui/components/progress.min.css';
import 'semantic-ui/components/reset.min.css';
import 'semantic-ui/components/progress.min.css';
import 'semantic-ui/components/segment.min.css';
import 'semantic-ui/components/sidebar.min.css';
import 'semantic-ui/components/site.min.css';
import 'semantic-ui/components/table.min.css';
import 'semantic-ui/components/transition.min.css';

import 'semantic-ui/components/accordion';
import 'semantic-ui/components/checkbox';
import 'semantic-ui/components/dimmer';
import 'semantic-ui/components/dropdown';
import 'semantic-ui/components/modal';
import 'semantic-ui/components/popup';
import 'semantic-ui/components/sidebar';
import 'semantic-ui/components/transition';
